# 5R1C Building Simulation Model

![Python application](https://github.com/architecture-building-systems/RC_BuildingSimulator/workflows/Python%20application/badge.svg)

## 10min Guide to your first simulation

See the [10min guide in the wiki page](https://github.com/architecture-building-systems/RC_BuildingSimulator/wiki/10min-guide-to-your-first-simulation)

## Developer Material

Can be found in [the wiki](https://github.com/architecture-building-systems/RC_BuildingSimulator/wiki)

## Academic Citations

If citing this simulator in research, please use the following reference

Jayathissa, Prageeth, et al. "Optimising building net energy demand with dynamic BIPV shading." Applied Energy 202 (2017): 726-735.

## References

Madsen, Henrik, and Jan Holst. "Estimation of continuous-time models for the heat dynamics of a building." Energy and Buildings 22.1 (1995): 67-79.

Bacher, Peder, and Henrik Madsen. "Identifying suitable models for the heat dynamics of buildings." Energy and Buildings 43.7 (2011): 1511-1522.

Sonderegger, Robert. "Diagnostic tests determining the thermal response of a house." Lawrence Berkeley National Laboratory (2010).

